# okcolor
_Generates aesthetically pleasing RGB colors_

# Install
```bash
python3 -m pip install okcolor
```

# Usage
To generate RGB values:
```python
from okcolor import colors
tuple(colors.visualize(sat=0.5, val=0.95))
```

To visualize random RGB values:
```python
colors.visualize()
```
![Screen Shot 2022-10-13 at 11 46 50 PM](https://user-images.githubusercontent.com/24948340/195758007-37126352-1776-44e5-adcf-0fdd512c6243.png)

# License
Under [MIT License](https://github.com/pncnmnp/okcolor/blob/master/LICENSE)
